pub struct LogGuard(/* private fields */);Expand description
Wraps the WorkerGuard from tracing-appender.
Must be kept alive until the end of main() to guarantee that the
non-blocking log writer flushes its buffer before the process exits.