pub fn print_library_not_found_hint()Expand description
Prints a user-friendly hint when the requested library was not found.
Called from dispatchers in cli.rs before propagating the error,
so the user sees the hint on stderr before the error message.